@@ -8,15 +8,20 @@ ALICE = Coin("ALICE")
 AMP = Coin("AMP")
 ANKR = Coin("ANKR")
 AR = Coin("AR")
+ARPA = Coin("ARPA")
 ATOM = Coin("ATOM")
 AUDIO = Coin("AUDIO")
 AVAX = Coin("AVAX")
 AXS = Coin("AXS")
+BADGER = Coin("BADGER")
 BAL = Coin("BAL")
 BAND = Coin("BAND")
 BAT = Coin("BAT")
 BCH = Coin("BCH")
+BICO = Coin("BICO")
 BNT = Coin("BNT")
+BOBA = Coin("BOBA")
+BOND = Coin("BOND")
 BOSON = Coin("BOSON")
 BRZ = Coin("BRZ")
 BTC = Coin("BTC")
@@ -34,14 +39,19 @@ CRV = Coin("CRV")
 CSPR = Coin("CSPR")
 CTSI = Coin("CTSI")
 DAI = Coin("DAI")
+DAR = Coin("DAR")
 DERC = Coin("DERC")
+DINO = Coin("DINO")
 DOGE = Coin("DOGE")
 DOT = Coin("DOT")
 DYDX = Coin("DYDX")
 EFI = Coin("EFI")
 EGLD = Coin("EGLD")
+ELON = Coin("ELON")
 ENJ = Coin("ENJ")
+ENS = Coin("ENS")
 EOS = Coin("EOS")
+EPS = Coin("EPS")
 ETC = Coin("ETC")
 ETH = Coin("ETH")
 FARM = Coin("FARM")
@@ -51,18 +61,26 @@ FLOW = Coin("FLOW")
 FORTH = Coin("FORTH")
 FTM = Coin("FTM")
 FXS = Coin("FXS")
+GALA = Coin("GALA")
 GHST = Coin("GHST")
+GLM = Coin("GLM")
+GODS = Coin("GODS")
 GRT = Coin("GRT")
 GTC = Coin("GTC")
 GUSD = Coin("GUSD")
+HBAR = Coin("HBAR")
 HNT = Coin("HNT")
+HOD = Coin("HOD")
 HOT = Coin("HOT")
 HUSD = Coin("HUSD")
 ICP = Coin("ICP")
 ICX = Coin("ICX")
 ILV = Coin("ILV")
+IMX = Coin("IMX")
 INJ = Coin("INJ")
+IOTX = Coin("IOTX")
 IQ = Coin("IQ")
+JASMY = Coin("JASMY")
 KAVA = Coin("KAVA")
 KEEP = Coin("KEEP")
 KLAY = Coin("KLAY")
@@ -80,44 +98,61 @@ MCO = Coin("MCO")
 MIR = Coin("MIR")
 MKR = Coin("MKR")
 MLN = Coin("MLN")
+MOVR = Coin("MOVR")
 NANO = Coin("NANO")
 NEAR = Coin("NEAR")
 NEO = Coin("NEO")
 NKN = Coin("NKN")
+NMR = Coin("NMR")
+NU = Coin("NU")
 OCEAN = Coin("OCEAN")
 OGN = Coin("OGN")
 OMG = Coin("OMG")
 ONE = Coin("ONE")
 ONEINCH = Coin("1INCH")
 ONT = Coin("ONT")
+OXT = Coin("OXT")
 PAXG = Coin("PAXG")
 PENDLE = Coin("PENDLE")
+PERP = Coin("PERP")
 PLA = Coin("PLA")
+POLS = Coin("POLS")
 POLY = Coin("POLY")
+POWR = Coin("POWR")
+QI = Coin("QI")
 QNT = Coin("QNT")
 QTUM = Coin("QTUM")
 QUICK = Coin("QUICK")
 RAD = Coin("RAD")
 RARI = Coin("RARI")
 REN = Coin("REN")
+REQ = Coin("REQ")
+RGT = Coin("RGT")
 RLC = Coin("RLC")
 RLY = Coin("RLY")
+RNDR = Coin("RNDR")
 RSR = Coin("RSR")
 RUNE = Coin("RUNE")
 RVN = Coin("RVN")
 SAND = Coin("SAND")
 SC = Coin("SC")
+SDN = Coin("SDN")
+SGB = Coin("SGB")
 SHIB = Coin("SHIB")
 SKL = Coin("SKL")
 SLP = Coin("SLP")
 SNX = Coin("SNX")
 SOL = Coin("SOL")
+SRM = Coin("SRM")
 STORJ = Coin("STORJ")
 STX = Coin("STX")
 SUSHI = Coin("SUSHI")
 TFUEL = Coin("TFUEL")
 THETA = Coin("THETA")
+TONIC = Coin("TONIC")
 TRB = Coin("TRB")
+TRIBE = Coin("TRIBE")
+TRU = Coin("TRU")
 TUSD = Coin("TUSD")
 UMA = Coin("UMA")
 UNI = Coin("UNI")
@@ -126,12 +161,15 @@ USDP = Coin("USDP")
 USDT = Coin("USDT")
 VET = Coin("VET")
 VTHO = Coin("VTHO")
+VVS = Coin("VVS")
 WAVE = Coin("WAVE")
 WAVES = Coin("WAVES")
+WAXP = Coin("WAXP")
 WBTC = Coin("WBTC")
 XLM = Coin("XLM")
 XRP = Coin("XRP")
 XTZ = Coin("XTZ")
+XYO = Coin("XYO")
 YFI = Coin("YFI")
 YGG = Coin("YGG")
 ZIL = Coin("ZIL")
