@@ -15,6 +15,7 @@ ALGO_USDT = Pair("ALGO_USDT", price_precision=4, quantity_precision=2)
 ALICE_USDT = Pair("ALICE_USDT", price_precision=3, quantity_precision=3)
 AMP_USDT = Pair("AMP_USDT", price_precision=5, quantity_precision=1)
 ANKR_USDT = Pair("ANKR_USDT", price_precision=6, quantity_precision=1)
+ARPA_USDC = Pair("ARPA_USDC", price_precision=5, quantity_precision=1)
 AR_USDC = Pair("AR_USDC", price_precision=3, quantity_precision=3)
 ATOM_BTC = Pair("ATOM_BTC", price_precision=7, quantity_precision=2)
 ATOM_CRO = Pair("ATOM_CRO", price_precision=2, quantity_precision=2)
@@ -24,6 +25,7 @@ AVAX_BTC = Pair("AVAX_BTC", price_precision=7, quantity_precision=3)
 AVAX_USDC = Pair("AVAX_USDC", price_precision=3, quantity_precision=3)
 AVAX_USDT = Pair("AVAX_USDT", price_precision=3, quantity_precision=3)
 AXS_USDT = Pair("AXS_USDT", price_precision=4, quantity_precision=2)
+BADGER_USDT = Pair("BADGER_USDT", price_precision=3, quantity_precision=3)
 BAL_CRO = Pair("BAL_CRO", price_precision=2, quantity_precision=3)
 BAL_USDT = Pair("BAL_USDT", price_precision=3, quantity_precision=3)
 BAND_CRO = Pair("BAND_CRO", price_precision=3, quantity_precision=2)
@@ -35,13 +37,16 @@ BCH_CRO = Pair("BCH_CRO", price_precision=2, quantity_precision=3)
 BCH_USDT = Pair("BCH_USDT", price_precision=2, quantity_precision=5)
 BNT_CRO = Pair("BNT_CRO", price_precision=3, quantity_precision=2)
 BNT_USDT = Pair("BNT_USDT", price_precision=4, quantity_precision=3)
+BOND_USDC = Pair("BOND_USDC", price_precision=3, quantity_precision=3)
 BOSON_USDT = Pair("BOSON_USDT", price_precision=4, quantity_precision=2)
+BRZ_USDT = Pair("BRZ_USDT", price_precision=5, quantity_precision=1)
 BTC_USDC = Pair("BTC_USDC", price_precision=2, quantity_precision=6)
 BTC_USDT = Pair("BTC_USDT", price_precision=2, quantity_precision=6)
 C98_USDT = Pair("C98_USDT", price_precision=4, quantity_precision=2)
 CELR_CRO = Pair("CELR_CRO", price_precision=5, quantity_precision=1)
 CELR_USDT = Pair("CELR_USDT", price_precision=6, quantity_precision=1)
 CHR_USDT = Pair("CHR_USDT", price_precision=5, quantity_precision=1)
+CHZ_BTC = Pair("CHZ_BTC", price_precision=10, quantity_precision=1)
 CHZ_USDT = Pair("CHZ_USDT", price_precision=5, quantity_precision=2)
 CKB_USDT = Pair("CKB_USDT", price_precision=6, quantity_precision=0)
 COMP_CRO = Pair("COMP_CRO", price_precision=2, quantity_precision=3)
@@ -57,6 +62,7 @@ CTSI_USDT = Pair("CTSI_USDT", price_precision=5, quantity_precision=1)
 DAI_CRO = Pair("DAI_CRO", price_precision=3, quantity_precision=3)
 DAI_USDC = Pair("DAI_USDC", price_precision=4, quantity_precision=2)
 DAI_USDT = Pair("DAI_USDT", price_precision=4, quantity_precision=3)
+DAR_USDT = Pair("DAR_USDT", price_precision=4, quantity_precision=2)
 DERC_USDT = Pair("DERC_USDT", price_precision=4, quantity_precision=2)
 DOGE_BTC = Pair("DOGE_BTC", price_precision=10, quantity_precision=1)
 DOGE_CRO = Pair("DOGE_CRO", price_precision=4, quantity_precision=2)
@@ -72,12 +78,15 @@ EFI_BTC = Pair("EFI_BTC", price_precision=9, quantity_precision=2)
 EFI_USDT = Pair("EFI_USDT", price_precision=4, quantity_precision=2)
 EGLD_CRO = Pair("EGLD_CRO", price_precision=3, quantity_precision=2)
 EGLD_USDT = Pair("EGLD_USDT", price_precision=4, quantity_precision=3)
+ELON_USDT = Pair("ELON_USDT", price_precision=10, quantity_precision=0)
 ENJ_BTC = Pair("ENJ_BTC", price_precision=9, quantity_precision=2)
 ENJ_CRO = Pair("ENJ_CRO", price_precision=3, quantity_precision=2)
 ENJ_USDC = Pair("ENJ_USDC", price_precision=4, quantity_precision=2)
 ENJ_USDT = Pair("ENJ_USDT", price_precision=5, quantity_precision=1)
+ENS_USDT = Pair("ENS_USDT", price_precision=3, quantity_precision=3)
 EOS_BTC = Pair("EOS_BTC", price_precision=8, quantity_precision=2)
 EOS_USDT = Pair("EOS_USDT", price_precision=4, quantity_precision=2)
+EPS_USDT = Pair("EPS_USDT", price_precision=5, quantity_precision=1)
 ETC_BTC = Pair("ETC_BTC", price_precision=7, quantity_precision=3)
 ETC_USDT = Pair("ETC_USDT", price_precision=3, quantity_precision=3)
 ETH_BTC = Pair("ETH_BTC", price_precision=6, quantity_precision=5)
@@ -94,20 +103,31 @@ FORTH_USDT = Pair("FORTH_USDT", price_precision=3, quantity_precision=3)
 FTM_BTC = Pair("FTM_BTC", price_precision=9, quantity_precision=2)
 FTM_USDT = Pair("FTM_USDT", price_precision=4, quantity_precision=2)
 FXS_USDC = Pair("FXS_USDC", price_precision=4, quantity_precision=2)
+GALA_BTC = Pair("GALA_BTC", price_precision=9, quantity_precision=1)
+GALA_USDT = Pair("GALA_USDT", price_precision=6, quantity_precision=0)
 GHST_USDC = Pair("GHST_USDC", price_precision=4, quantity_precision=2)
+GLM_USDT = Pair("GLM_USDT", price_precision=5, quantity_precision=1)
+GODS_USDT = Pair("GODS_USDT", price_precision=4, quantity_precision=2)
 GRT_CRO = Pair("GRT_CRO", price_precision=3, quantity_precision=2)
 GRT_USDT = Pair("GRT_USDT", price_precision=5, quantity_precision=2)
 GTC_USDT = Pair("GTC_USDT", price_precision=3, quantity_precision=3)
 HNT_USDT = Pair("HNT_USDT", price_precision=3, quantity_precision=3)
+HOD_USDT = Pair("HOD_USDT", price_precision=6, quantity_precision=0)
 HOT_CRO = Pair("HOT_CRO", price_precision=5, quantity_precision=0)
 HOT_USDT = Pair("HOT_USDT", price_precision=6, quantity_precision=0)
+ICP_BTC = Pair("ICP_BTC", price_precision=8, quantity_precision=0)
 ICP_USDT = Pair("ICP_USDT", price_precision=3, quantity_precision=3)
 ICX_BTC = Pair("ICX_BTC", price_precision=8, quantity_precision=1)
 ICX_CRO = Pair("ICX_CRO", price_precision=3, quantity_precision=0)
 ICX_USDT = Pair("ICX_USDT", price_precision=4, quantity_precision=2)
+ILV_BTC = Pair("ILV_BTC", price_precision=6, quantity_precision=4)
 ILV_USDT = Pair("ILV_USDT", price_precision=2, quantity_precision=4)
+IMX_USDC = Pair("IMX_USDC", price_precision=4, quantity_precision=2)
 INJ_USDT = Pair("INJ_USDT", price_precision=3, quantity_precision=3)
+IOTX_USDC = Pair("IOTX_USDC", price_precision=6, quantity_precision=0)
+IOTX_USDT = Pair("IOTX_USDT", price_precision=5, quantity_precision=1)
 IQ_USDT = Pair("IQ_USDT", price_precision=6, quantity_precision=0)
+JASMY_USDT = Pair("JASMY_USDT", price_precision=5, quantity_precision=1)
 KAVA_USDT = Pair("KAVA_USDT", price_precision=4, quantity_precision=2)
 KEEP_USDT = Pair("KEEP_USDT", price_precision=5, quantity_precision=1)
 KLAY_USDT = Pair("KLAY_USDT", price_precision=4, quantity_precision=2)
@@ -130,6 +150,7 @@ LUNA_USDC = Pair("LUNA_USDC", price_precision=3, quantity_precision=3)
 LUNA_USDT = Pair("LUNA_USDT", price_precision=4, quantity_precision=2)
 MANA_BTC = Pair("MANA_BTC", price_precision=9, quantity_precision=1)
 MANA_CRO = Pair("MANA_CRO", price_precision=3, quantity_precision=2)
+MANA_USDC = Pair("MANA_USDC", price_precision=4, quantity_precision=2)
 MANA_USDT = Pair("MANA_USDT", price_precision=5, quantity_precision=2)
 MASK_USDT = Pair("MASK_USDT", price_precision=4, quantity_precision=2)
 MATIC_BTC = Pair("MATIC_BTC", price_precision=9, quantity_precision=0)
@@ -147,19 +168,28 @@ NEO_BTC = Pair("NEO_BTC", price_precision=7, quantity_precision=3)
 NEO_CRO = Pair("NEO_CRO", price_precision=3, quantity_precision=2)
 NEO_USDT = Pair("NEO_USDT", price_precision=3, quantity_precision=4)
 NKN_USDT = Pair("NKN_USDT", price_precision=5, quantity_precision=1)
+NMR_USDT = Pair("NMR_USDT", price_precision=3, quantity_precision=3)
+NU_USDC = Pair("NU_USDC", price_precision=4, quantity_precision=2)
 OCEAN_USDT = Pair("OCEAN_USDT", price_precision=4, quantity_precision=2)
 OGN_USDT = Pair("OGN_USDT", price_precision=4, quantity_precision=2)
 OMG_BTC = Pair("OMG_BTC", price_precision=8, quantity_precision=4)
 OMG_CRO = Pair("OMG_CRO", price_precision=3, quantity_precision=2)
 OMG_USDT = Pair("OMG_USDT", price_precision=4, quantity_precision=4)
 ONEINCH_USDT = Pair("1INCH_USDT", price_precision=4, quantity_precision=2)
+ONE_BTC = Pair("ONE_BTC", price_precision=10, quantity_precision=1)
+ONE_USDC = Pair("ONE_USDC", price_precision=5, quantity_precision=1)
 ONE_USDT = Pair("ONE_USDT", price_precision=5, quantity_precision=1)
 ONT_BTC = Pair("ONT_BTC", price_precision=8, quantity_precision=2)
 ONT_USDT = Pair("ONT_USDT", price_precision=4, quantity_precision=2)
+OXT_USDT = Pair("OXT_USDT", price_precision=5, quantity_precision=1)
 PAXG_USDT = Pair("PAXG_USDT", price_precision=2, quantity_precision=5)
 PENDLE_USDT = Pair("PENDLE_USDT", price_precision=5, quantity_precision=1)
+PERP_USDT = Pair("PERP_USDT", price_precision=3, quantity_precision=3)
 PLA_USDT = Pair("PLA_USDT", price_precision=5, quantity_precision=1)
+POLS_USDT = Pair("POLS_USDT", price_precision=4, quantity_precision=2)
 POLY_USDC = Pair("POLY_USDC", price_precision=5, quantity_precision=1)
+POWR_USDT = Pair("POWR_USDT", price_precision=5, quantity_precision=1)
+QI_USDT = Pair("QI_USDT", price_precision=5, quantity_precision=1)
 QNT_USDC = Pair("QNT_USDC", price_precision=2, quantity_precision=4)
 QNT_USDT = Pair("QNT_USDT", price_precision=2, quantity_precision=4)
 QTUM_CRO = Pair("QTUM_CRO", price_precision=3, quantity_precision=2)
@@ -168,14 +198,17 @@ QUICK_USDT = Pair("QUICK_USDT", price_precision=2, quantity_precision=4)
 RAD_USDC = Pair("RAD_USDC", price_precision=3, quantity_precision=3)
 RARI_USDC = Pair("RARI_USDC", price_precision=3, quantity_precision=3)
 RARI_USDT = Pair("RARI_USDT", price_precision=3, quantity_precision=3)
-REN_CRO = Pair("REN_CRO", price_precision=4, quantity_precision=2)
 REN_USDT = Pair("REN_USDT", price_precision=5, quantity_precision=2)
+REQ_USDT = Pair("REQ_USDT", price_precision=5, quantity_precision=1)
+RGT_USDC = Pair("RGT_USDC", price_precision=3, quantity_precision=3)
 RLC_USDT = Pair("RLC_USDT", price_precision=3, quantity_precision=3)
 RLY_USDT = Pair("RLY_USDT", price_precision=5, quantity_precision=2)
+RNDR_USDT = Pair("RNDR_USDT", price_precision=4, quantity_precision=2)
 RSR_USDT = Pair("RSR_USDT", price_precision=5, quantity_precision=1)
 RUNE_USDT = Pair("RUNE_USDT", price_precision=3, quantity_precision=3)
 SAND_USDT = Pair("SAND_USDT", price_precision=5, quantity_precision=2)
 SC_USDT = Pair("SC_USDT", price_precision=6, quantity_precision=0)
+SDN_USDT = Pair("SDN_USDT", price_precision=4, quantity_precision=2)
 SHIB_USDC = Pair("SHIB_USDC", price_precision=9, quantity_precision=0)
 SHIB_USDT = Pair("SHIB_USDT", price_precision=9, quantity_precision=0)
 SKL_USDT = Pair("SKL_USDT", price_precision=5, quantity_precision=2)
@@ -185,14 +218,15 @@ SNX_USDT = Pair("SNX_USDT", price_precision=3, quantity_precision=3)
 SOL_BTC = Pair("SOL_BTC", price_precision=7, quantity_precision=3)
 SOL_USDC = Pair("SOL_USDC", price_precision=3, quantity_precision=3)
 SOL_USDT = Pair("SOL_USDT", price_precision=3, quantity_precision=3)
+SRM_USDC = Pair("SRM_USDC", price_precision=4, quantity_precision=2)
 STORJ_USDT = Pair("STORJ_USDT", price_precision=4, quantity_precision=2)
 STX_USDT = Pair("STX_USDT", price_precision=4, quantity_precision=2)
 SUSHI_USDT = Pair("SUSHI_USDT", price_precision=3, quantity_precision=3)
 TFUEL_USDT = Pair("TFUEL_USDT", price_precision=5, quantity_precision=1)
 THETA_USDT = Pair("THETA_USDT", price_precision=4, quantity_precision=2)
 TRB_USDT = Pair("TRB_USDT", price_precision=3, quantity_precision=3)
-UMA_BTC = Pair("UMA_BTC", price_precision=7, quantity_precision=4)
-UMA_CRO = Pair("UMA_CRO", price_precision=2, quantity_precision=4)
+TRIBE_USDT = Pair("TRIBE_USDT", price_precision=4, quantity_precision=2)
+TRU_USDT = Pair("TRU_USDT", price_precision=5, quantity_precision=1)
 UMA_USDT = Pair("UMA_USDT", price_precision=3, quantity_precision=4)
 UNI_CRO = Pair("UNI_CRO", price_precision=3, quantity_precision=2)
 UNI_USDC = Pair("UNI_USDC", price_precision=3, quantity_precision=3)
@@ -203,11 +237,13 @@ VET_CRO = Pair("VET_CRO", price_precision=4, quantity_precision=0)
 VET_USDC = Pair("VET_USDC", price_precision=6, quantity_precision=0)
 VET_USDT = Pair("VET_USDT", price_precision=6, quantity_precision=0)
 VTHO_USDT = Pair("VTHO_USDT", price_precision=6, quantity_precision=0)
+VVS_USDC = Pair("VVS_USDC", price_precision=8, quantity_precision=0)
 WAVES_USDT = Pair("WAVES_USDT", price_precision=3, quantity_precision=3)
+WAXP_USDT = Pair("WAXP_USDT", price_precision=5, quantity_precision=1)
 WBTC_BTC = Pair("WBTC_BTC", price_precision=4, quantity_precision=6)
+WBTC_USDC = Pair("WBTC_USDC", price_precision=2, quantity_precision=6)
 WBTC_USDT = Pair("WBTC_USDT", price_precision=2, quantity_precision=6)
 XLM_BTC = Pair("XLM_BTC", price_precision=9, quantity_precision=0)
-XLM_CRO = Pair("XLM_CRO", price_precision=3, quantity_precision=2)
 XLM_USDT = Pair("XLM_USDT", price_precision=5, quantity_precision=1)
 XRP_BTC = Pair("XRP_BTC", price_precision=9, quantity_precision=0)
 XRP_CRO = Pair("XRP_CRO", price_precision=3, quantity_precision=0)
@@ -216,9 +252,11 @@ XRP_USDT = Pair("XRP_USDT", price_precision=5, quantity_precision=1)
 XTZ_BTC = Pair("XTZ_BTC", price_precision=8, quantity_precision=2)
 XTZ_CRO = Pair("XTZ_CRO", price_precision=3, quantity_precision=2)
 XTZ_USDT = Pair("XTZ_USDT", price_precision=4, quantity_precision=2)
+XYO_USDT = Pair("XYO_USDT", price_precision=6, quantity_precision=0)
 YFI_BTC = Pair("YFI_BTC", price_precision=4, quantity_precision=6)
 YFI_CRO = Pair("YFI_CRO", price_precision=2, quantity_precision=6)
 YFI_USDT = Pair("YFI_USDT", price_precision=2, quantity_precision=6)
+YGG_BTC = Pair("YGG_BTC", price_precision=8, quantity_precision=2)
 YGG_USDT = Pair("YGG_USDT", price_precision=4, quantity_precision=2)
 ZIL_CRO = Pair("ZIL_CRO", price_precision=4, quantity_precision=2)
 ZIL_USDT = Pair("ZIL_USDT", price_precision=5, quantity_precision=1)
